pub struct OAuthFlow {
pub authorization_url: String,
pub pkce_verifier: String,
pub state: String,
}Expand description
OAuth authorization flow information
Contains the authorization URL and PKCE verifier needed to complete the OAuth flow.
Fields
The URL the user should visit to authorize the application
pkce_verifier: StringThe PKCE verifier used to exchange the authorization code for tokens
state: StringThe CSRF state token for security validation